from PIL import Image
import os
import sys


def resize_image(image_path, output_path, target_width):
    """
    Resizes an image to the specified width while maintaining aspect ratio.
    Saves the resized image to the specified output path.
    """
    with Image.open(image_path) as img:
        width_percent = (target_width / float(img.size[0]))
        target_height = int((float(img.size[1]) * float(width_percent)))
        img = img.resize((target_width, target_height), Image.LANCZOS)
        img.save(output_path)


def process_images_in_folder(folder_path, target_width):
    """
    Processes all JPEG images in the specified folder.
    Resizes each image to the target width, maintaining aspect ratio.
    Skips images that already have the 'resized_' prefix or corresponding 'resized_' version exists.
    """
    for filename in os.listdir(folder_path):
        if (filename.lower().endswith('.jpeg') or filename.lower().endswith('.jpg')) and not filename.startswith(
                'resized_'):
            resized_filename = f"resized_{filename}"
            if resized_filename not in os.listdir(folder_path):
                image_path = os.path.join(folder_path, filename)
                output_path = os.path.join(folder_path, resized_filename)
                print(image_path)
                resize_image(image_path, output_path, target_width)


if __name__ == "__main__":
    # Determine the application path
    config_name = 'myapp.cfg'

    if getattr(sys, 'frozen', False):
        # Running in a bundle (PyInstaller)
        application_path = os.path.dirname(sys.executable)
        running_mode = 'Frozen/executable'
    else:
        try:
            # Running in a regular Python environment
            app_full_path = os.path.realpath(__file__)
            application_path = os.path.dirname(app_full_path)
            running_mode = "Non-interactive (e.g. 'python myapp.py')"
        except NameError:
            # Running in an interactive environment (e.g., Jupyter Notebook)
            application_path = os.getcwd()
            running_mode = 'Interactive'

    config_full_path = os.path.join(application_path, config_name)

    # Output running mode and application path
    print('Running mode:', running_mode)
    print('Application path:', application_path)

    # Change working directory to the application path
    os.chdir(application_path)

    # Process images in the application path directory
    process_images_in_folder(application_path, 1920)
